pub struct ChatMessageEntry {
pub message: Message,
pub received_at: DateTime<Utc>,
}Expand description
Represents a chat message along with its reception timestamp.
Fields
message: MessageThe actual Message content.
received_at: DateTime<Utc>The DateTime when the message was received by the UI.